@@ -1,13 +1,19 @@
+skip_if_not_installed("rush")
+skip_if_no_redis()
+
+
 test_that("ArchiveAsyncFrozen works", {
-  skip_on_cran()
-  skip_if_not_installed("rush")
-  flush_redis()
+  rush = start_rush()
+  on.exit({
+    rush$reset()
+    mirai::daemons(0)
+  })
 
-  rush::rush_plan(n_workers = 2)
   instance = oi_async(
     objective = OBJ_2D,
     search_space = PS_2D,
     terminator = trm("evals", n_evals = 5L),
+    rush = rush
   )
 
   optimizer = opt("async_random_search")
