@@ -1,104 +1,52 @@
-test_that("OptimizerAsync starts local workers", {
-  skip_on_cran()
-  skip_if_not_installed("rush")
-  flush_redis()
-  library(rush)
+skip_if_not_installed("rush")
+skip_if_no_redis()
 
-  mirai::daemons(2)
-  rush::rush_plan(n_workers = 2, worker_type = "remote")
-
-  instance = oi_async(
-    objective = OBJ_2D,
-    search_space = PS_2D,
-    terminator = trm("evals", n_evals = 50L),
-  )
-
-  optimizer = opt("async_random_search")
-  optimizer$optimize(instance)
-
-  expect_data_table(instance$rush$worker_info, nrows = 2)
-  expect_list(instance$rush$processes_mirai, len = 2)
-
-  expect_rush_reset(instance$rush)
-})
-
-test_that("OptimizerAsync starts remote workers", {
-  skip_on_cran()
-  skip_if_not_installed(c("rush", "mirai"))
-  flush_redis()
-  library(rush)
-
-  mirai::daemons(2)
-  rush_plan(n_workers = 2, worker_type = "remote")
+test_that("OptimizerAsync starts workers", {
+  rush = start_rush(n_workers = 1, worker_type = "remote") # FIXME: change to "mirai" after rush 1.0.0 is released
+  on.exit({
+    rush$reset()
+    mirai::daemons(0)
+  })
 
   instance = oi_async(
     objective = OBJ_2D,
     search_space = PS_2D,
     terminator = trm("evals", n_evals = 5L),
+    rush = rush
   )
 
   optimizer = opt("async_random_search")
   optimizer$optimize(instance)
 
-  expect_data_table(instance$rush$worker_info, nrows = 2)
-  expect_list(instance$rush$processes_mirai, len = 2)
-
-  expect_rush_reset(instance$rush)
-})
-
-test_that("OptimizerAsync defaults to local worker", {
-  skip_on_cran()
-  skip_if_not_installed("rush")
-  flush_redis()
-  library(rush)
-
-  mirai::daemons(2)
-  rush::rush_plan(n_workers = 2, worker_type = "remote")
-
-  instance = oi_async(
-    objective = OBJ_2D,
-    search_space = PS_2D,
-    terminator = trm("evals", n_evals = 50L),
-  )
-
-  optimizer = opt("async_random_search")
-  optimizer$optimize(instance)
-
-  expect_data_table(instance$rush$worker_info, nrows = 2)
-
-  expect_rush_reset(instance$rush)
+  expect_data_table(instance$rush$worker_info, nrows = 1)
+  expect_list(instance$rush$processes_mirai, len = 1)
 })
 
 test_that("OptimizerAsync assigns result", {
-  skip_on_cran()
-  skip_if_not_installed("rush")
-  flush_redis()
-  library(rush)
-
-  mirai::daemons(2)
-  rush::rush_plan(n_workers = 2, worker_type = "remote")
+  rush = start_rush()
+  on.exit({
+    rush$reset()
+    mirai::daemons(0)
+  })
 
   instance = oi_async(
     objective = OBJ_2D,
     search_space = PS_2D,
     terminator = trm("evals", n_evals = 5L),
+    rush = rush
   )
   optimizer = opt("async_random_search")
   optimizer$optimize(instance)
 
   expect_data_table(instance$result, nrows = 1)
-
-  expect_rush_reset(instance$rush)
 })
 
 test_that("OptimizerAsync throws an error when all workers are lost", {
-  skip_on_cran()
-  skip_if_not_installed("rush")
-  flush_redis()
-  library(rush)
-
-  mirai::daemons(2)
-  rush::rush_plan(n_workers = 2, worker_type = "remote")
+  rush = start_rush()
+  on.exit({
+    rush$reset()
+    mirai::daemons(0)
+  })
 
   objective = ObjectiveRFun$new(
     fun = function(xs) {
@@ -112,27 +60,25 @@ test_that("OptimizerAsync throws an error when all workers are lost", {
     objective = objective,
     search_space = PS_2D,
     terminator = trm("evals", n_evals = 5L),
+    rush = rush
   )
   optimizer = opt("async_random_search")
 
   expect_error(optimizer$optimize(instance), "Optimization terminated without any finished evaluations")
-
-  expect_rush_reset(instance$rush)
 })
 
 test_that("restarting the optimization works", {
-  skip_on_cran()
-  skip_if_not_installed("rush")
-  flush_redis()
-  library(rush)
-
-  mirai::daemons(2)
-  rush::rush_plan(n_workers = 2, worker_type = "remote")
+  rush = start_rush()
+  on.exit({
+    rush$reset()
+    mirai::daemons(0)
+  })
 
   instance = oi_async(
     objective = OBJ_2D,
     search_space = PS_2D,
     terminator = trm("evals", n_evals = 5L),
+    rush = rush
   )
 
   optimizer = opt("async_random_search")
@@ -148,22 +94,20 @@ test_that("restarting the optimization works", {
   optimizer$optimize(instance)
 
   expect_data_table(instance$archive$data, min.rows = 30L)
-  expect_rush_reset(instance$rush)
 })
 
 test_that("Queued tasks are failed when optimization is terminated", {
-  skip_on_cran()
-  skip_if_not_installed("rush")
-  flush_redis()
-  library(rush)
-
-  mirai::daemons(2)
-  rush::rush_plan(n_workers = 2, worker_type = "remote")
+  rush = start_rush()
+  on.exit({
+    rush$reset()
+    mirai::daemons(0)
+  })
 
   instance = oi_async(
     objective = OBJ_2D,
     search_space = PS_2D,
     terminator = trm("run_time", secs = 1),
+    rush = rush
   )
 
   optimizer = opt("async_design_points", design = data.table(x1 = runif(5000L), x2 = runif(5000L)))
@@ -171,17 +115,14 @@ test_that("Queued tasks are failed when optimization is terminated", {
 
   expect_true(instance$rush$n_failed_tasks > 0L)
   expect_data_table(instance$archive$data[list("failed"), on = "state"], min.rows = 1L)
-  expect_rush_reset(instance$rush)
 })
 
 test_that("Required packages are loaded", {
-  skip_on_cran()
-  skip_if_not_installed("rush")
-  flush_redis()
-  library(rush)
-
-  mirai::daemons(2)
-  rush::rush_plan(n_workers = 2, worker_type = "remote")
+  rush = start_rush()
+  on.exit({
+    rush$reset()
+    mirai::daemons(0)
+  })
 
   objective = ObjectiveRFun$new(
     fun = function(xs) {
@@ -200,6 +141,7 @@ test_that("Required packages are loaded", {
     objective = objective,
     search_space = PS_2D,
     terminator = trm("evals", n_evals = 5L),
+    rush = rush
   )
 
   optimizer = opt("async_random_search")
@@ -225,10 +167,11 @@ test_that("Required packages are loaded", {
     objective = objective,
     search_space = PS_2D,
     terminator = trm("evals", n_evals = 5L),
+    rush = rush
   )
 
   optimizer = opt("async_random_search")
   optimizer$optimize(instance)
 
-  expect_set_equal(instance$archive$data$y, 1)
+  expect_set_equal(instance$archive$data[list("finished"), on = "state"]$y, 1)
 })
