@@ -23,3 +23,17 @@ test_that("man exists", {
   terminator = trm("stagnation")
   expect_man_exists(terminator$man)
 })
+
+test_that("TerminatorStagnation errors with direction=0 (learn tag)", {
+  terminator = TerminatorStagnation$new()
+  codomain = ps(y = p_dbl(tags = "learn"))
+  archive = ArchiveBatch$new(ps(x = p_dbl()), codomain)
+
+  # add some evaluations
+  xdt = data.table(x = c(0.5, 0.3))
+  xss_trafoed = list(list(x = 0.5), list(x = 0.3))
+  ydt = data.table(y = c(0.25, 0.09))
+  archive$add_evals(xdt, xss_trafoed, ydt)
+
+  expect_error(terminator$is_terminated(archive), "direction != 0")
+})
